@@ -1,5 +1,6 @@
 #include <Rcpp.h>
 #include "shared.h"
+// [[Rcpp::interfaces(r, cpp)]]
 // [[Rcpp::plugins(cpp11)]]
 
 using std::pow;
@@ -25,23 +26,27 @@ using Rcpp::NumericVector;
  * 
  */
 
-inline double pdf_ht(double x, double nu, double sigma,
-                     bool& throw_warning) {
+inline double logpdf_ht(double x, double nu, double sigma,
+                        bool& throw_warning) {
+#ifdef IEEE_754
   if (ISNAN(x) || ISNAN(nu) || ISNAN(sigma))
     return x+nu+sigma;
+#endif
   if (sigma <= 0.0 || nu <= 0.0) {
     throw_warning = true;
     return NAN;
   }
   if (x < 0.0)
-    return 0.0;
-  return 2.0 * R::dt(x/sigma, nu, false)/sigma;
+    return R_NegInf;
+  return LOG_2F + R::dt(x/sigma, nu, true) - log(sigma);
 }
 
 inline double cdf_ht(double x, double nu, double sigma,
                      bool& throw_warning) {
+#ifdef IEEE_754
   if (ISNAN(x) || ISNAN(nu) || ISNAN(sigma))
     return x+nu+sigma;
+#endif
   if (sigma <= 0.0 || nu <= 0.0) {
     throw_warning = true;
     return NAN;
@@ -53,8 +58,10 @@ inline double cdf_ht(double x, double nu, double sigma,
 
 inline double invcdf_ht(double p, double nu, double sigma,
                         bool& throw_warning) {
+#ifdef IEEE_754
   if (ISNAN(p) || ISNAN(nu) || ISNAN(sigma))
     return p+nu+sigma;
+#endif
   if (sigma <= 0.0 || nu <= 0.0 || !VALID_PROB(p)) {
     throw_warning = true;
     return NAN;
@@ -93,11 +100,11 @@ NumericVector cpp_dht(
   bool throw_warning = false;
   
   for (int i = 0; i < Nmax; i++) 
-    p[i] = pdf_ht(GETV(x, i), GETV(nu, i),
-                  GETV(sigma, i), throw_warning);
+    p[i] = logpdf_ht(GETV(x, i), GETV(nu, i),
+                     GETV(sigma, i), throw_warning);
   
-  if (log_prob)
-    p = Rcpp::log(p);
+  if (!log_prob)
+    p = Rcpp::exp(p);
   
   if (throw_warning)
     Rcpp::warning("NaNs produced");
